# GcodeFile


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [readonly] 
**user** | **int** |  | [readonly] 
**name** | **str** |  | 
**file** | **str** |  | 
**file_hash** | **str** |  | 
**octoprint_device** | **str** |  | 
**url** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


